﻿''' <summary>
''' Sample application for the VC940 class.
''' </summary>
''' <remarks></remarks>
Public Class frmMain

    ' Define the object that is used to communicate with the VC940 multimeter
    Private WithEvents multimeter As New VC940



    ''' <summary>
    ''' multimeter_measurementReceived is called when new data is received
    ''' </summary>
    ''' <param name="type">type of measurement</param>
    ''' <param name="unit">the unit of the measurement</param>
    ''' <param name="value">the measured value</param>
    ''' <param name="overrange">a boolean to indicate if the measurement is in overrange</param>
    ''' <remarks></remarks>
    Private Sub multimeter_measurementReceived(type As String, unit As String, value As String, overrange As Boolean) Handles multimeter.measurementReceived

        If overrange Then
            lblStatus.Text = "OVR"
        Else
            lblStatus.Text = String.Format("{0} {1}", value, unit)
        End If
    End Sub



    ''' <summary>
    ''' cmdConnect_Click is called when the connect/disconnect button is clicked.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks></remarks>
    Private Sub cmdConnect_Click(sender As System.Object, e As System.EventArgs) Handles cmdConnect.Click

        If multimeter.isConnected Then

            multimeter.disconnect()

            MsgBox("Multimeter disconnected.",
                 MsgBoxStyle.OkOnly + MsgBoxStyle.Information,
                 "Multimeter connected")

        Else
            Dim text As String =
                InputBox("Please enter your COM port number",
                          "Enter COM-port",
                          "1")

            If text <> "" Then
                Dim comPort As Integer

                If Integer.TryParse(text, comPort) Then

                    multimeter.comPort = comPort
                    If multimeter.connect() Then
                        MsgBox("Multimeter connected. Waiting for data!",
                             MsgBoxStyle.OkOnly + MsgBoxStyle.Information,
                             "Multimeter connected")
                    Else
                        MsgBox("Connection failed: check connection with the multimeter",
                             MsgBoxStyle.OkOnly + MsgBoxStyle.Information,
                             "Connection failed")
                    End If

                Else
                    MsgBox("Invalid COM-port entered!",
                         MsgBoxStyle.OkOnly + MsgBoxStyle.Information,
                         "Invalid COM port")
                End If ' Integer.TryParse(text, comPort) Then
            End If ' text <> "" Then
        End If ' multimeter.isConnected Then
    End Sub




    ''' <summary>
    ''' frmMain_Load will initialize the form
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks></remarks>
    Private Sub frmMain_Load(sender As System.Object, e As System.EventArgs) Handles MyBase.Load
        ' This statement is needed to pass the object reference of the owner form (this form)
        ' to the multimeter object. This statement makes sure you can access the GUI directly
        ' from the multimeter_measurementReceived method.
        multimeter.ownerForm = Me
    End Sub
End Class
